﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using CoreGraphics;
using Foundation;
using UIKit;
using WebKit;

namespace XFPDF.iOS
{
    public class CustomWebView : WKNavigationDelegate
    {
        string filePath = null;

        public CustomWebView(string path)
        {
            this.filePath = path;
        }

        public override void DidFinishNavigation(WKWebView webView, WKNavigation navigation)
        {
            double height, width;
            int header, sidespace;
            width = 595.2;
            height = 841.8;
            header = 10;
            sidespace = 10;
            UIEdgeInsets pageMargins = new UIEdgeInsets(header, sidespace, header, sidespace);
            webView.ViewPrintFormatter.ContentInsets = pageMargins;
            UIPrintPageRenderer renderer = new UIPrintPageRenderer();
            renderer.AddPrintFormatter(webView.ViewPrintFormatter, 0);
            CGSize pageSize = new CGSize(width, height);
            CGRect printableRect = new CGRect(sidespace,
                              header,
                              pageSize.Width - (sidespace * 2),
                              pageSize.Height - (header * 2));
            CGRect paperRect = new CGRect(0, 0, width, height);
            
            var nSString = new NSString("PaperRect");
            var printableRectstring = new NSString("PrintableRect");
           
            renderer.SetValueForKey(NSValue.FromObject(paperRect), nSString);
            renderer.SetValueForKey(NSValue.FromObject(printableRect), printableRectstring);
            NSData file = PrintToPDFWithRenderer(renderer, paperRect);
            File.WriteAllBytes(filePath, file.ToArray());
        }

        private NSData PrintToPDFWithRenderer(UIPrintPageRenderer renderer, CGRect paperRect)
        {
            NSMutableData pdfData = new NSMutableData();
            UIGraphics.BeginPDFContext(pdfData, paperRect, null);
            renderer.PrepareForDrawingPages(new NSRange(0, renderer.NumberOfPages));
            CGRect bounds = UIGraphics.PDFContextBounds;
            for (int i = 0; i < renderer.NumberOfPages; i++)
            {
                UIGraphics.BeginPDFPage();
                renderer.DrawPage(i, paperRect);
            }
            UIGraphics.EndPDFContent();
            System.Diagnostics.Debug.WriteLine("EndOfPDFDocument");
            return pdfData;
        }
    }
}